import static org.junit.Assert.assertEquals;

import org.junit.Before;
import org.junit.Test;
import org.owasp.validator.html.AntiSamy;
import org.owasp.validator.html.CleanResults;
import org.owasp.validator.html.Policy;



public class AntiSamyScanTest
{

	private Policy policy;
	private AntiSamy as;

	@Before
	public void before() throws Exception
	{
		policy = Policy.getInstance( "src/test/resources/antisamy-myspace.xml" );
		as = new AntiSamy( policy );
	}

	@Test
	public void legalScan() throws Exception
	{
		CleanResults cleanResults = as.scan( "<a href=\"http://www.legal.org\">legale</a>" );
		assertEquals( 0, cleanResults.getErrorMessages().size() );
		assertEquals( "<a href=\"http://www.legal.org\">legale</a>", cleanResults.getCleanHTML() );
	}

	@Test
	public void illegalScriptTagScan() throws Exception
	{
		CleanResults cleanResults = as.scan( "<script>alert('xss');</script>" );
		assertEquals( 1, cleanResults.getErrorMessages().size() );
		assertEquals( "", cleanResults.getCleanHTML() );
	}

	@Test
	public void illegalOnclickHandlerScan() throws Exception
	{
		CleanResults cleanResults = as
				.scan( "<a href=\"http://www.illegal.org\" onclick=\"alert('xss');\">illegale</a>" );
		assertEquals( 1, cleanResults.getErrorMessages().size() );
		assertEquals( "<a href=\"http://www.illegal.org\">illegale</a>",
				cleanResults.getCleanHTML() );
	}
}
